@@ -1,10 +1,12 @@
 from .routes import (
-    Routes,
-    SubRoutes,
+    ASGIRoute,
+    FileRoutes,
     HttpRoute,
-    SocketRoute,
     NoMatchFound,
     NoRouteFound,
+    Routes,
+    SocketRoute,
+    SubRoutes,
 )
 
 __all__ = [
@@ -12,6 +14,8 @@ __all__ = [
     "SubRoutes",
     "HttpRoute",
     "SocketRoute",
+    "ASGIRoute",
+    "FileRoutes",
     "NoMatchFound",
     "NoRouteFound",
 ]
